@@ -1,40 +1,40 @@
 var languageNames = {
-"en-US": "English (USA)",
-"am": "Amharic",
-"ar": "Arabic",
-"ast": "Asturian",
-"bg": "Bulgarian",
-"bn": "Bengali",
-"bn-IN": "Bengali (India)",
-"bo": "Tibetan",
-"bs": "Bosnian",
-"ca": "Catalan",
-"ca-valencia": "Valencian Catalan",
-"cs": "Czech",
-"da": "Danish",
-"de": "German",
+"en-US": "Inglés (EXA)",
+"am": "Amáricu",
+"ar": "Árabe",
+"ast": "Asturianu",
+"bg": "Búlgaru",
+"bn": "Bengalín",
+"bn-IN": "Bengalín (India)",
+"bo": "Tibetanu",
+"bs": "Bosniu",
+"ca": "Catalán",
+"ca-valencia": "Catalán (valencianu)",
+"cs": "Checu",
+"da": "Danés",
+"de": "Alemán",
 "dz": "Butanés",
-"el": "Greek",
-"en-GB": "English (UK)",
-"en-ZA": "English (SA)",
-"eo": "Esperanto",
+"el": "Griegu",
+"en-GB": "Inglés (RX)",
+"en-ZA": "Inglés (Sudáf.)",
+"eo": "Esperantu",
 "es": "Spanish",
-"et": "Estonian",
+"et": "Estoniu",
 "eu": "Vascu",
 "fi": "Finnish",
-"fr": "French",
-"gl": "Galician",
+"fr": "Francés",
+"gl": "Gallegu",
 "gu": "Gujarati",
 "he": "Hebréu",
 "hi": "Hindi",
 "hr": "Croatian",
 "hu": "Hungarian",
-"id": "Indonesian",
+"id": "Indonesiu",
 "is": "Icelandic",
-"it": "Italian",
-"ja": "Japanese",
-"ka": "Georgian",
-"km": "Khmer",
+"it": "Italianu",
+"ja": "Xaponés",
+"ka": "Xeorxanu",
+"km": "Ḥemer",
 "ko": "Korean",
 "lo": "Lao",
 "lt": "Lithuanian",
@@ -47,7 +47,7 @@ var languageNames = {
 "om": "Oromo",
 "pl": "Polish",
 "pt": "Portuguese",
-"pt-BR": "Brazilian Portuguese",
+"pt-BR": "Portugués (brasilanu)",
 "ro": "Romanian",
 "ru": "Russian",
 "si": "Sinhala",
@@ -60,8 +60,8 @@ var languageNames = {
 "tg": "Tajik",
 "tr": "Turkish",
 "ug": "Uyghur",
-"uk": "Ukrainian",
+"uk": "Ucraín",
 "vi": "Vietnamese",
-"zh-CN": "Chinese (Simplified)",
-"zh-TW": "Chinese (Traditional)",
+"zh-CN": "Chinu (simplificáu)",
+"zh-TW": "Chinu (tradicional)",
 };
